@@ -232,15 +232,15 @@ def alist_batch_download(
         full_predicate = lambda path: strm_predicate(path) or predicate(path)
     if sync:
         seen: dict[str, bool] = {}
-        local_dir_len = len(local_dir) + 1
+        local_local_reldirlen = len(local_dir) + 1
         def clean():
             dq = deque((local_dir,))
             push = dq.append
             pop = dq.pop
             while dq:
-                dir_ = pop()
-                for entry in scandir(dir_):
-                    path = entry.path[local_dir_len:]
+                local_reldir = pop()
+                for entry in scandir(local_reldir):
+                    path = entry.path[local_local_reldirlen:]
                     try:
                         if entry.is_dir(follow_symlinks=False):
                             if path + sep in seen:
@@ -267,7 +267,7 @@ def alist_batch_download(
                 if use_strm:
                     local_path = splitext(local_path)[0] + ".strm"
                 if sync:
-                    seen[local_path[local_dir_len:]] = False
+                    seen[local_path[local_local_reldirlen:]] = False
                 if custom_url is None:
                     url = path.get_url()
                 else:
@@ -321,13 +321,13 @@ def alist_batch_download(
                                 await write(chunk)
                     logger and logger.info(f"\x1b[1;32mDOWNLOADED\x1b[0m: \x1b[4;34m{local_path!r}\x1b[0m")
                 if sync:
-                    seen[local_path[local_dir_len:]] = True
+                    seen[local_path[local_local_reldirlen:]] = True
             except:
                 logger and logger.exception(f"\x1b[1;31mFAILED\x1b[0m: \x1b[4;34m{local_path!r}\x1b[0m")
         async def request():
             async with TaskGroup() as tg:
                 create_task = tg.create_task
-                dir_ = "."
+                local_reldir = "."
                 async for path in client.fs.iter(
                     remote_dir, 
                     max_depth=-1, 
@@ -338,15 +338,15 @@ def alist_batch_download(
                     async_=True, 
                 ):
                     local_relpath = normpath(path.relative_to(remote_dir))
-                    if dir_ != (dir_ := dirname(local_relpath)):
-                        local_dir = joinpath(local_dir, dir_)
+                    if local_reldir != (local_reldir := dirname(local_relpath)):
+                        dir_ = joinpath(local_dir, local_reldir)
                         try:
-                            await to_thread(makedirs, local_dir, exist_ok=True)
+                            await to_thread(makedirs, dir_, exist_ok=True)
                         except FileExistsError:
-                            await to_thread(remove, local_dir)
-                            await to_thread(makedirs, local_dir)
+                            await to_thread(remove, dir_)
+                            await to_thread(makedirs, dir_)
                         if sync:    
-                            dir0 = dir_
+                            dir0 = local_reldir
                             while dir0:
                                 seen[dir0 + sep] = True
                                 dir0 = dirname(dir0)
@@ -361,7 +361,7 @@ def alist_batch_download(
                 if use_strm:
                     local_path = splitext(local_path)[0] + ".strm"
                 if sync:
-                    seen[local_path[local_dir_len:]] = False
+                    seen[local_path[local_local_reldirlen:]] = False
                 if custom_url is None:
                     url = path.get_url()
                 else:
@@ -410,14 +410,14 @@ def alist_batch_download(
                             write(chunk)
                     logger and logger.info(f"\x1b[1;32mDOWNLOADED\x1b[0m: \x1b[4;34m{local_path!r}\x1b[0m")
                 if sync:
-                    seen[local_path[local_dir_len:]] = True
+                    seen[local_path[local_local_reldirlen:]] = True
             except:
                 logger and logger.exception(f"\x1b[1;31mFAILED\x1b[0m: \x1b[4;34m{local_path!r}\x1b[0m")
         executor = ThreadPoolExecutor(max_workers=max_workers)
         try:
             with executor:
                 submit = executor.submit
-                dir_ = ""
+                local_reldir = ""
                 for path in client.fs.iter(
                     remote_dir, 
                     max_depth=-1, 
@@ -427,15 +427,15 @@ def alist_batch_download(
                     onerror=True, 
                 ):
                     local_relpath = normpath(path.relative_to(remote_dir))
-                    if dir_ != (dir_ := dirname(local_relpath)):
-                        local_dir = joinpath(local_dir, dir_)
+                    if local_reldir != (local_reldir := dirname(local_relpath)):
+                        dir_ = joinpath(local_dir, local_reldir)
                         try:
-                            makedirs(local_dir, exist_ok=True)
+                            makedirs(dir_, exist_ok=True)
                         except FileExistsError:
-                            remove(local_dir)
-                            makedirs(local_dir, exist_ok=True)
+                            remove(dir_)
+                            makedirs(dir_, exist_ok=True)
                         if sync:    
-                            dir0 = dir_
+                            dir0 = local_reldir
                             while dir0:
                                 seen[dir0 + sep] = True
                                 dir0 = dirname(dir0)
